@@ -201,6 +201,8 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 		Long: heredoc.Docf(`
 			Create a pull request on GitHub.
 
+			Upon success, the URL of the created pull request will be printed.
+
 			When the current branch isn't fully pushed to a git remote, a prompt will ask where
 			to push the branch and offer an option to fork the base repository. Use %[1]s--head%[1]s to
 			explicitly skip any forking or pushing behavior.
@@ -386,13 +388,17 @@ func createRun(opts *CreateOptions) error {
 		return err
 	}
 
+	if opts.TitleProvided {
+		state.Title = opts.Title
+	}
+
+	if opts.BodyProvided {
+		state.Body = opts.Body
+	}
+
 	var openURL string
 
 	if opts.WebMode {
-		if !(opts.Autofill || opts.FillFirst) {
-			state.Title = opts.Title
-			state.Body = opts.Body
-		}
 		if opts.Template != "" {
 			state.Template = opts.Template
 		}
@@ -411,14 +417,6 @@ func createRun(opts *CreateOptions) error {
 		return previewPR(*opts, openURL)
 	}
 
-	if opts.TitleProvided {
-		state.Title = opts.Title
-	}
-
-	if opts.BodyProvided {
-		state.Body = opts.Body
-	}
-
 	existingPR, _, err := opts.Finder.Find(shared.FindOptions{
 		Selector:   ctx.PRRefs.QualifiedHeadRef(),
 		BaseBranch: ctx.PRRefs.BaseRef(),
